@@ -1,4 +1,4 @@
-{-# OPTIONS -cpp -fglasgow-exts #-}
+{-# LANGUAGE CPP, BangPatterns, MagicHash, UnboxedTuples #-}
 --
 -- (c) The University of Glasgow 2002
 --
@@ -11,8 +11,12 @@ module FastMutInt(
 
 #define SIZEOF_HSINT  4
 
-import GHC.Base
-import GHC.IOBase
+import GHC.Exts
+# if __GLASGOW_HASKELL__>=612
+import GHC.IO     (IO(IO))
+#else
+import GHC.IOBase (IO(IO))
+#endif
 
 data FastMutInt = FastMutInt (MutableByteArray# RealWorld)
 
