@@ -4,11 +4,11 @@ where
 -- version number is major.minor.patchlvl; don't change the format of the
 -- `versnum' line as it is `grep'ed for by a Makefile
 --
-idstr      = "$Id: Version.hs,v 1.1 2004/11/21 21:05:42 as49 Exp $"
+idstr      = "$Id: Version.hs,v 1.1 2012/05/27 16:49:07 dmwit Exp $"
 name       = "C->Haskell Compiler"
-versnum    = "0.13.5 (gtk2hs branch)"
+versnum    = "0.13.6 (gtk2hs branch)"
 versnick   = "\"Bin IO\""
-date	   = "13 Nov 2004"
+date	   = "27 May 2012"
 version    = name ++ ", version " ++ versnum ++ " " ++ versnick ++ ", " ++ date
 copyright  = "Copyright (c) [1999..2004] Manuel M T Chakravarty"
 disclaimer = "This software is distributed under the \
